@@ -713,19 +713,38 @@ class CustomGenericRelationForm(forms.ModelForm):
         else:
             log.warning("highlighter was false")
 
-        self.helper.include_media = False
-        self.helper.layout = Layout(
-                'relation_type',
-                'target',
-                'start_date_written',
-                'end_date_written',
-                Accordion(
-                        AccordionGroup(
-                                'Notes and References',
-                                'notes',
-                                'references',
-                                active=False,
-                                css_id="{}_{}_notes_refs".format(self.relation_form.__name__, css_notes))))
+        if self.relation_form.__name__.lower() == "personinstitution":
+            self.fields["write citation"] = forms.BooleanField()
+            self.fields["write citation"].initial = True
+            self.fields["write citation"].required = False
+            self.helper.include_media = False
+            self.helper.layout = Layout(
+            'relation_type',
+            'target',
+            'start_date_written',
+            'end_date_written',
+            'write citation',
+            Accordion(
+                    AccordionGroup(
+                            'Notes and References',
+                            'notes',
+                            'references',
+                            active=False,
+                            css_id="{}_{}_notes_refs".format(self.relation_form.__name__, css_notes))))
+        else:
+            self.helper.include_media = False
+            self.helper.layout = Layout(
+                    'relation_type',
+                    'target',
+                    'start_date_written',
+                    'end_date_written',
+                    Accordion(
+                            AccordionGroup(
+                                    'Notes and References',
+                                    'notes',
+                                    'references',
+                                    active=False,
+                                    css_id="{}_{}_notes_refs".format(self.relation_form.__name__, css_notes))))
 
         if highlighter:
             self.fields['HL_start'] = forms.IntegerField(widget=forms.HiddenInput)
