@@ -1028,8 +1028,11 @@ class GenericEntitiesCreateView(View):
             #  apis-instances
             name = self.request.POST["name"]
             ent_class = AbstractEntity.get_entity_class_of_name(entity.title())
-            exists_test = ent_class.objects.filter(name=name)
-
+            #exists_test = ent_class.objects.filter(name=name)
+            if ent_class == "Person":
+                exists_test = False
+            else:
+                exists_test = ent_class.objects.filter(name=name)
             if exists_test:
                 success = False
                 res_msg = f"{entity.title()}-Instance with name {name} already exists. No action taken."
@@ -1258,7 +1261,8 @@ def save_custom_ajax_form(request, entity_type, kind_form, SiteID,
         log.info(f"instance name {instance}, {instance.__class__.__name__}")
         if not instance.__class__.__name__ == "Label":
             save_to_collection(instance, col)
-            save_citation(instance, citation, page_token)
+            if request.POST.get("write citation"):
+                save_citation(instance, citation, page_token)
 
         if kind_form == "PersonInstitutionForm":
             update_pagedata(instance, pagedata)
@@ -1384,7 +1388,7 @@ class CustomTableActionButtonView(View):
         was_saved = True
         if year:
             year = int(year)
-        year_written = f"<{year}-06-30>"
+        year_written = f"{year}<{year}-06-30>"
         serialization = get_json_rel(rel_id=rel.id,
                                      rel_class=rel_class.__name__)
         sd = rel.start_date
